==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/block/BlockTypeGroup.java <==
package cc.thonly.reverie_dreams.block;

import cc.thonly.mystias_izakaya.block.kitchenware.AbstractKitchenwareBlock;
import lombok.Getter;
import net.minecraft.block.*;
import net.minecraft.class_1792;
import net.minecraft.class_2248;
import net.minecraft.class_2261;
import net.minecraft.class_2269;
import net.minecraft.class_2323;
import net.minecraft.class_2349;
import net.minecraft.class_2354;
import net.minecraft.class_2397;
import net.minecraft.class_2440;
import net.minecraft.class_2482;
import net.minecraft.class_2510;
import net.minecraft.class_2533;
import java.util.Collection;
import java.util.LinkedHashSet;
import java.util.Objects;
import java.util.Set;
import java.util.stream.Stream;

@Getter
public enum BlockTypeGroup {
    BLOCK(),
    PLANT(),
    SAPLING(),
    FENCE(),
    FENCE_GATE(),
    WALL(),
    LEAVES(),
    STAIR(),
    SLAB(),
    BUTTON(),
    PRESSURE_PLATE(),
    TRAPDOOR(),
    DOOR(),
    FRUIT_LEAVES(),
    PICKAXE_MINEABLE(),
    AXE_MINEABLE(),
    SHOVEL_MINEABLE(),
    HOE_MINEABLE(),
    SWORD_MINEABLE(),
    KITCHENWARE(),
    ;
    private final Set<class_2248> entries = new LinkedHashSet<>();

    BlockTypeGroup() {
    }

    public static void join(class_2248 block) {
        if (block instanceof class_2354) {
            FENCE.add(block);
        }
        if (block instanceof class_2349) {
            FENCE_GATE.add(block);
        }
        if (block instanceof class_2510) {
            STAIR.add(block);
        }
        if (block instanceof class_2482) {
            SLAB.add(block);
        }
        if (block instanceof class_2269) {
            BUTTON.add(block);
        }
        if (block instanceof class_2440) {
            PRESSURE_PLATE.add(block);
        }
        if (block instanceof class_2533) {
            TRAPDOOR.add(block);
        }
        if (block instanceof class_2323) {
            DOOR.add(block);
        }
        if (block instanceof class_2397) {
            LEAVES.add(block);
        }
        if (block instanceof AbstractKitchenwareBlock) {
            KITCHENWARE.add(block);
        }
        if (block instanceof class_2261) {
            PLANT.add(block);
        }
        BLOCK.add(block);
    }

    public void add(class_2248 block) {
        this.entries.add(block);
    }

    public Stream<class_2248> stream() {
        return this.entries.stream();
    }

    public Collection<class_1792> items() {
        return Set.copyOf(this.entries.stream().map(class_2248::method_8389).filter(Objects::nonNull).toList());
    }

    public Collection<class_2248> blocks() {
        return Set.copyOf(this.entries);
    }
}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/block/BlockTypeGroup.java <==
package cc.thonly.reverie_dreams.block;

import cc.thonly.reverie_dreams.block.kitchen.AbstractKitchenwareBlock;
import lombok.Getter;
import net.minecraft.class_1792;
import net.minecraft.class_2248;
import net.minecraft.class_2261;
import net.minecraft.class_2269;
import net.minecraft.class_2323;
import net.minecraft.class_2349;
import net.minecraft.class_2354;
import net.minecraft.class_2397;
import net.minecraft.class_2440;
import net.minecraft.class_2482;
import net.minecraft.class_2510;
import net.minecraft.class_2533;
import net.minecraft.class_2544;
import net.minecraft.world.level.block.*;

import java.util.Collection;
import java.util.LinkedHashSet;
import java.util.Objects;
import java.util.Set;
import java.util.stream.Stream;

@Getter
public enum BlockTypeGroup {
    BLOCK(),
    PLANT(),
    SAPLING(),
    FENCE(),
    FENCE_GATE(),
    WALL(),
    LEAVES(),
    STAIR(),
    SLAB(),
    BUTTON(),
    PRESSURE_PLATE(),
    TRAPDOOR(),
    DOOR(),
    FRUIT_LEAVES(),
    PICKAXE_MINEABLE(),
    AXE_MINEABLE(),
    SHOVEL_MINEABLE(),
    HOE_MINEABLE(),
    SWORD_MINEABLE(),
    KITCHENWARE(),
    ;
    private final Set<class_2248> entries = new LinkedHashSet<>();

    BlockTypeGroup() {
    }

    public static void join(class_2248 block) {
        if (block instanceof class_2354) {
            FENCE.add(block);
        }
        if (block instanceof class_2349) {
            FENCE_GATE.add(block);
        }
        if (block instanceof class_2510) {
            STAIR.add(block);
        }
        if (block instanceof class_2482) {
            SLAB.add(block);
        }
        if (block instanceof class_2269) {
            BUTTON.add(block);
        }
        if (block instanceof class_2440) {
            PRESSURE_PLATE.add(block);
        }
        if (block instanceof class_2533) {
            TRAPDOOR.add(block);
        }
        if (block instanceof class_2323) {
            DOOR.add(block);
        }
        if (block instanceof class_2397) {
            LEAVES.add(block);
        }
        if (block instanceof class_2544) {
            WALL.add(block);
        }
        if (block instanceof AbstractKitchenwareBlock) {
            KITCHENWARE.add(block);
        }
        if (block instanceof class_2261) {
            PLANT.add(block);
        }
        BLOCK.add(block);
    }

    public void add(class_2248 block) {
        this.entries.add(block);
    }

    public Stream<class_2248> stream() {
        return this.entries.stream();
    }

    public Collection<class_1792> items() {
        return Set.copyOf(this.entries.stream().map(class_2248::method_8389).filter(Objects::nonNull).toList());
    }

    public Collection<class_2248> blocks() {
        return Set.copyOf(this.entries);
    }
}
